@@ -1,7 +1,7 @@
  #!/usr/bin/env python
 """__init__ file for interator module."""
 
-from interator import (prime_stream, composite_stream, polygonal_stream,
+from .interator import (prime_stream, composite_stream, polygonal_stream,
                        fibonacci_stream, negafibonacci_stream, lucas_stream,
                        is_prime, miller_rabin, is_composite, is_polygonal,
                        is_fibonacci, is_lucas, nth_fibonacci)
